Class: Aws::QBusiness::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::QBusiness::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-qbusiness/client.rb
Overview
An API client for QBusiness. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::QBusiness::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_permission(params = {}) ⇒ Types::AssociatePermissionResponse
Adds or updates a permission policy for a Amazon Q Business application, allowing cross-account access for an ISV.
-
#batch_delete_document(params = {}) ⇒ Types::BatchDeleteDocumentResponse
Asynchronously deletes one or more documents added using the ‘BatchPutDocument` API from an Amazon Q Business index.
-
#batch_put_document(params = {}) ⇒ Types::BatchPutDocumentResponse
Adds one or more documents to an Amazon Q Business index.
-
#cancel_subscription(params = {}) ⇒ Types::CancelSubscriptionResponse
Unsubscribes a user or a group from their pricing tier in an Amazon Q Business application.
-
#chat_sync(params = {}) ⇒ Types::ChatSyncOutput
Starts or continues a non-streaming Amazon Q Business conversation.
-
#check_document_access(params = {}) ⇒ Types::CheckDocumentAccessResponse
Verifies if a user has access permissions for a specified document and returns the actual ACL attached to the document.
-
#create_anonymous_web_experience_url(params = {}) ⇒ Types::CreateAnonymousWebExperienceUrlResponse
Creates a unique URL for anonymous Amazon Q Business web experience.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an Amazon Q Business application.
-
#create_chat_response_configuration(params = {}) ⇒ Types::CreateChatResponseConfigurationResponse
Creates a new chat response configuration for an Amazon Q Business application.
-
#create_data_accessor(params = {}) ⇒ Types::CreateDataAccessorResponse
Creates a new data accessor for an ISV to access data from a Amazon Q Business application.
-
#create_data_source(params = {}) ⇒ Types::CreateDataSourceResponse
Creates a data source connector for an Amazon Q Business application.
-
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an Amazon Q Business index.
-
#create_plugin(params = {}) ⇒ Types::CreatePluginResponse
Creates an Amazon Q Business plugin.
-
#create_retriever(params = {}) ⇒ Types::CreateRetrieverResponse
Adds a retriever to your Amazon Q Business application.
-
#create_subscription(params = {}) ⇒ Types::CreateSubscriptionResponse
Subscribes an IAM Identity Center user or a group to a pricing tier for an Amazon Q Business application.
-
#create_user(params = {}) ⇒ Struct
Creates a universally unique identifier (UUID) mapped to a list of local user ids within an application.
-
#create_web_experience(params = {}) ⇒ Types::CreateWebExperienceResponse
Creates an Amazon Q Business web experience.
-
#delete_application(params = {}) ⇒ Struct
Deletes an Amazon Q Business application.
-
#delete_attachment(params = {}) ⇒ Struct
Deletes an attachment associated with a specific Amazon Q Business conversation.
-
#delete_chat_controls_configuration(params = {}) ⇒ Struct
Deletes chat controls configured for an existing Amazon Q Business application.
-
#delete_chat_response_configuration(params = {}) ⇒ Struct
Deletes a specified chat response configuration from an Amazon Q Business application.
-
#delete_conversation(params = {}) ⇒ Struct
Deletes an Amazon Q Business web experience conversation.
-
#delete_data_accessor(params = {}) ⇒ Struct
Deletes a specified data accessor.
-
#delete_data_source(params = {}) ⇒ Struct
Deletes an Amazon Q Business data source connector.
-
#delete_group(params = {}) ⇒ Struct
Deletes a group so that all users and sub groups that belong to the group can no longer access documents only available to that group.
-
#delete_index(params = {}) ⇒ Struct
Deletes an Amazon Q Business index.
-
#delete_plugin(params = {}) ⇒ Struct
Deletes an Amazon Q Business plugin.
-
#delete_retriever(params = {}) ⇒ Struct
Deletes the retriever used by an Amazon Q Business application.
-
#delete_user(params = {}) ⇒ Struct
Deletes a user by email id.
-
#delete_web_experience(params = {}) ⇒ Struct
Deletes an Amazon Q Business web experience.
-
#disassociate_permission(params = {}) ⇒ Struct
Removes a permission policy from a Amazon Q Business application, revoking the cross-account access that was previously granted to an ISV.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets information about an existing Amazon Q Business application.
-
#get_chat_controls_configuration(params = {}) ⇒ Types::GetChatControlsConfigurationResponse
Gets information about chat controls configured for an existing Amazon Q Business application.
-
#get_chat_response_configuration(params = {}) ⇒ Types::GetChatResponseConfigurationResponse
Retrieves detailed information about a specific chat response configuration from an Amazon Q Business application.
-
#get_data_accessor(params = {}) ⇒ Types::GetDataAccessorResponse
Retrieves information about a specified data accessor.
-
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Gets information about an existing Amazon Q Business data source connector.
-
#get_document_content(params = {}) ⇒ Types::GetDocumentContentResponse
Retrieves the content of a document that was ingested into Amazon Q Business.
-
#get_group(params = {}) ⇒ Types::GetGroupResponse
Describes a group by group name.
-
#get_index(params = {}) ⇒ Types::GetIndexResponse
Gets information about an existing Amazon Q Business index.
-
#get_media(params = {}) ⇒ Types::GetMediaResponse
Returns the image bytes corresponding to a media object.
-
#get_plugin(params = {}) ⇒ Types::GetPluginResponse
Gets information about an existing Amazon Q Business plugin.
-
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Retrieves the current permission policy for a Amazon Q Business application.
-
#get_retriever(params = {}) ⇒ Types::GetRetrieverResponse
Gets information about an existing retriever used by an Amazon Q Business application.
-
#get_user(params = {}) ⇒ Types::GetUserResponse
Describes the universally unique identifier (UUID) associated with a local user in a data source.
-
#get_web_experience(params = {}) ⇒ Types::GetWebExperienceResponse
Gets information about an existing Amazon Q Business web experience.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists Amazon Q Business applications.
-
#list_attachments(params = {}) ⇒ Types::ListAttachmentsResponse
Gets a list of attachments associated with an Amazon Q Business web experience or a list of attachements associated with a specific Amazon Q Business conversation.
-
#list_chat_response_configurations(params = {}) ⇒ Types::ListChatResponseConfigurationsResponse
Retrieves a list of all chat response configurations available in a specified Amazon Q Business application.
-
#list_conversations(params = {}) ⇒ Types::ListConversationsResponse
Lists one or more Amazon Q Business conversations.
-
#list_data_accessors(params = {}) ⇒ Types::ListDataAccessorsResponse
Lists the data accessors for a Amazon Q Business application.
-
#list_data_source_sync_jobs(params = {}) ⇒ Types::ListDataSourceSyncJobsResponse
Get information about an Amazon Q Business data source connector synchronization.
-
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists the Amazon Q Business data source connectors that you have created.
-
#list_documents(params = {}) ⇒ Types::ListDocumentsResponse
A list of documents attached to an index.
-
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Provides a list of groups that are mapped to users.
-
#list_indices(params = {}) ⇒ Types::ListIndicesResponse
Lists the Amazon Q Business indices you have created.
-
#list_messages(params = {}) ⇒ Types::ListMessagesResponse
Gets a list of messages associated with an Amazon Q Business web experience.
-
#list_plugin_actions(params = {}) ⇒ Types::ListPluginActionsResponse
Lists configured Amazon Q Business actions for a specific plugin in an Amazon Q Business application.
-
#list_plugin_type_actions(params = {}) ⇒ Types::ListPluginTypeActionsResponse
Lists configured Amazon Q Business actions for any plugin type—both built-in and custom.
-
#list_plugin_type_metadata(params = {}) ⇒ Types::ListPluginTypeMetadataResponse
Lists metadata for all Amazon Q Business plugin types.
-
#list_plugins(params = {}) ⇒ Types::ListPluginsResponse
Lists configured Amazon Q Business plugins.
-
#list_retrievers(params = {}) ⇒ Types::ListRetrieversResponse
Lists the retriever used by an Amazon Q Business application.
-
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsResponse
Lists all subscriptions created in an Amazon Q Business application.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags associated with a specified resource.
-
#list_web_experiences(params = {}) ⇒ Types::ListWebExperiencesResponse
Lists one or more Amazon Q Business Web Experiences.
-
#put_feedback(params = {}) ⇒ Struct
Enables your end user to provide feedback on their Amazon Q Business generated chat responses.
-
#put_group(params = {}) ⇒ Struct
Create, or updates, a mapping of users—who have access to a document—to groups.
-
#search_relevant_content(params = {}) ⇒ Types::SearchRelevantContentResponse
Searches for relevant content in a Amazon Q Business application based on a query.
-
#start_data_source_sync_job(params = {}) ⇒ Types::StartDataSourceSyncJobResponse
Starts a data source connector synchronization job.
-
#stop_data_source_sync_job(params = {}) ⇒ Struct
Stops an Amazon Q Business data source connector synchronization job already in progress.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tag to the specified Amazon Q Business application or data source resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from an Amazon Q Business application or a data source.
-
#update_application(params = {}) ⇒ Struct
Updates an existing Amazon Q Business application.
-
#update_chat_controls_configuration(params = {}) ⇒ Struct
Updates a set of chat controls configured for an existing Amazon Q Business application.
-
#update_chat_response_configuration(params = {}) ⇒ Struct
Updates an existing chat response configuration in an Amazon Q Business application.
-
#update_data_accessor(params = {}) ⇒ Struct
Updates an existing data accessor.
-
#update_data_source(params = {}) ⇒ Struct
Updates an existing Amazon Q Business data source connector.
-
#update_index(params = {}) ⇒ Struct
Updates an Amazon Q Business index.
-
#update_plugin(params = {}) ⇒ Struct
Updates an Amazon Q Business plugin.
-
#update_retriever(params = {}) ⇒ Struct
Updates the retriever used for your Amazon Q Business application.
-
#update_subscription(params = {}) ⇒ Types::UpdateSubscriptionResponse
Updates the pricing tier for an Amazon Q Business subscription.
-
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Updates a information associated with a user id.
-
#update_web_experience(params = {}) ⇒ Struct
Updates an Amazon Q Business web experience.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
482 483 484 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 482 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6269 6270 6271 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 6269 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6272 6273 6274 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 6272 def errors_module Errors end |
Instance Method Details
#associate_permission(params = {}) ⇒ Types::AssociatePermissionResponse
Adds or updates a permission policy for a Amazon Q Business application, allowing cross-account access for an ISV. This operation creates a new policy statement for the specified Amazon Q Business application. The policy statement defines the IAM actions that the ISV is allowed to perform on the Amazon Q Business application’s resources.
542 543 544 545 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 542 def (params = {}, = {}) req = build_request(:associate_permission, params) req.send_request() end |
#batch_delete_document(params = {}) ⇒ Types::BatchDeleteDocumentResponse
Asynchronously deletes one or more documents added using the ‘BatchPutDocument` API from an Amazon Q Business index.
You can see the progress of the deletion, and any error messages related to the process, by using CloudWatch.
596 597 598 599 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 596 def batch_delete_document(params = {}, = {}) req = build_request(:batch_delete_document, params) req.send_request() end |
#batch_put_document(params = {}) ⇒ Types::BatchPutDocumentResponse
Adds one or more documents to an Amazon Q Business index.
You use this API to:
-
ingest your structured and unstructured documents and documents stored in an Amazon S3 bucket into an Amazon Q Business index.
-
add custom attributes to documents in an Amazon Q Business index.
-
attach an access control list to the documents added to an Amazon Q Business index.
You can see the progress of the deletion, and any error messages related to the process, by using CloudWatch.
777 778 779 780 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 777 def batch_put_document(params = {}, = {}) req = build_request(:batch_put_document, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 6242 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::QBusiness') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-qbusiness' context[:gem_version] = '1.59.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_subscription(params = {}) ⇒ Types::CancelSubscriptionResponse
Unsubscribes a user or a group from their pricing tier in an Amazon Q Business application. An unsubscribed user or group loses all Amazon Q Business feature access at the start of next month.
816 817 818 819 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 816 def cancel_subscription(params = {}, = {}) req = build_request(:cancel_subscription, params) req.send_request() end |
#chat_sync(params = {}) ⇒ Types::ChatSyncOutput
Starts or continues a non-streaming Amazon Q Business conversation.
1093 1094 1095 1096 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 1093 def chat_sync(params = {}, = {}) req = build_request(:chat_sync, params) req.send_request() end |
#check_document_access(params = {}) ⇒ Types::CheckDocumentAccessResponse
Verifies if a user has access permissions for a specified document and returns the actual ACL attached to the document. Resolves user access on the document via user aliases and groups when verifying user access.
1175 1176 1177 1178 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 1175 def check_document_access(params = {}, = {}) req = build_request(:check_document_access, params) req.send_request() end |
#create_anonymous_web_experience_url(params = {}) ⇒ Types::CreateAnonymousWebExperienceUrlResponse
Creates a unique URL for anonymous Amazon Q Business web experience. This URL can only be used once and must be used within 5 minutes after it’s generated.
1215 1216 1217 1218 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 1215 def create_anonymous_web_experience_url(params = {}, = {}) req = build_request(:create_anonymous_web_experience_url, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an Amazon Q Business application.
<note markdown=“1”> There are new tiers for Amazon Q Business. Not all features in Amazon Q Business Pro are also available in Amazon Q Business Lite. For information on what’s included in Amazon Q Business Lite and what’s included in Amazon Q Business Pro, see [Amazon Q Business tiers]. You must use the Amazon Q Business console to assign subscription tiers to users.
An Amazon Q Apps service linked role will be created if it's absent
in the Amazon Web Services account when ‘QAppsConfiguration` is enabled in the request. For more information, see [ Using service-linked roles for Q Apps].
When you create an application, Amazon Q Business may securely
transmit data for processing from your selected Amazon Web Services region, but within your geography. For more information, see [Cross region inference in Amazon Q Business].
</note>
[1]: docs.aws.amazon.com/amazonq/latest/qbusiness-ug/tiers.html#user-sub-tiers [2]: docs.aws.amazon.com/amazonq/latest/qbusiness-ug/using-service-linked-roles-qapps.html [3]: docs.aws.amazon.com/amazonq/latest/qbusiness-ug/cross-region-inference.html
1370 1371 1372 1373 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 1370 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_chat_response_configuration(params = {}) ⇒ Types::CreateChatResponseConfigurationResponse
Creates a new chat response configuration for an Amazon Q Business application. This operation establishes a set of parameters that define how the system generates and formats responses to user queries in chat interactions.
1448 1449 1450 1451 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 1448 def create_chat_response_configuration(params = {}, = {}) req = build_request(:create_chat_response_configuration, params) req.send_request() end |
#create_data_accessor(params = {}) ⇒ Types::CreateDataAccessorResponse
Creates a new data accessor for an ISV to access data from a Amazon Q Business application. The data accessor is an entity that represents the ISV’s access to the Amazon Q Business application’s data. It includes the IAM role ARN for the ISV, a friendly name, and a set of action configurations that define the specific actions the ISV is allowed to perform and any associated data filters. When the data accessor is created, an IAM Identity Center application is also created to manage the ISV’s identity and authentication for accessing the Amazon Q Business application.
1617 1618 1619 1620 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 1617 def create_data_accessor(params = {}, = {}) req = build_request(:create_data_accessor, params) req.send_request() end |
#create_data_source(params = {}) ⇒ Types::CreateDataSourceResponse
Creates a data source connector for an Amazon Q Business application.
‘CreateDataSource` is a synchronous operation. The operation returns 200 if the data source was successfully created. Otherwise, an exception is raised.
1836 1837 1838 1839 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 1836 def create_data_source(params = {}, = {}) req = build_request(:create_data_source, params) req.send_request() end |
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an Amazon Q Business index.
To determine if index creation has completed, check the ‘Status` field returned from a call to `DescribeIndex`. The `Status` field is set to `ACTIVE` when the index is ready to use.
Once the index is active, you can index your documents using the [ ‘BatchPutDocument` ][1] API or the [ `CreateDataSource` ][2] API.
[1]: docs.aws.amazon.com/amazonq/latest/api-reference/API_BatchPutDocument.html [2]: docs.aws.amazon.com/amazonq/latest/api-reference/API_CreateDataSource.html
1924 1925 1926 1927 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 1924 def create_index(params = {}, = {}) req = build_request(:create_index, params) req.send_request() end |
#create_plugin(params = {}) ⇒ Types::CreatePluginResponse
Creates an Amazon Q Business plugin.
2025 2026 2027 2028 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2025 def create_plugin(params = {}, = {}) req = build_request(:create_plugin, params) req.send_request() end |
#create_retriever(params = {}) ⇒ Types::CreateRetrieverResponse
Adds a retriever to your Amazon Q Business application.
2122 2123 2124 2125 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2122 def create_retriever(params = {}, = {}) req = build_request(:create_retriever, params) req.send_request() end |
#create_subscription(params = {}) ⇒ Types::CreateSubscriptionResponse
Subscribes an IAM Identity Center user or a group to a pricing tier for an Amazon Q Business application.
Amazon Q Business offers two subscription tiers: ‘Q_LITE` and `Q_BUSINESS`. Subscription tier determines feature access for the user. For more information on subscriptions and pricing tiers, see [Amazon Q Business pricing].
<note markdown=“1”> For an example IAM role policy for assigning subscriptions, see [Set up required permissions] in the Amazon Q Business User Guide.
</note>
[1]: aws.amazon.com/q/business/pricing/ [2]: docs.aws.amazon.com/amazonq/latest/qbusiness-ug/setting-up.html#permissions
2194 2195 2196 2197 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2194 def create_subscription(params = {}, = {}) req = build_request(:create_subscription, params) req.send_request() end |
#create_user(params = {}) ⇒ Struct
Creates a universally unique identifier (UUID) mapped to a list of local user ids within an application.
2240 2241 2242 2243 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2240 def create_user(params = {}, = {}) req = build_request(:create_user, params) req.send_request() end |
#create_web_experience(params = {}) ⇒ Types::CreateWebExperienceResponse
Creates an Amazon Q Business web experience.
2374 2375 2376 2377 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2374 def create_web_experience(params = {}, = {}) req = build_request(:create_web_experience, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes an Amazon Q Business application.
2396 2397 2398 2399 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2396 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_attachment(params = {}) ⇒ Struct
Deletes an attachment associated with a specific Amazon Q Business conversation.
2432 2433 2434 2435 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2432 def (params = {}, = {}) req = build_request(:delete_attachment, params) req.send_request() end |
#delete_chat_controls_configuration(params = {}) ⇒ Struct
Deletes chat controls configured for an existing Amazon Q Business application.
2456 2457 2458 2459 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2456 def delete_chat_controls_configuration(params = {}, = {}) req = build_request(:delete_chat_controls_configuration, params) req.send_request() end |
#delete_chat_response_configuration(params = {}) ⇒ Struct
Deletes a specified chat response configuration from an Amazon Q Business application.
2485 2486 2487 2488 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2485 def delete_chat_response_configuration(params = {}, = {}) req = build_request(:delete_chat_response_configuration, params) req.send_request() end |
#delete_conversation(params = {}) ⇒ Struct
Deletes an Amazon Q Business web experience conversation.
2517 2518 2519 2520 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2517 def delete_conversation(params = {}, = {}) req = build_request(:delete_conversation, params) req.send_request() end |
#delete_data_accessor(params = {}) ⇒ Struct
Deletes a specified data accessor. This operation permanently removes the data accessor and its associated IAM Identity Center application. Any access granted to the ISV through this data accessor will be revoked.
2546 2547 2548 2549 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2546 def delete_data_accessor(params = {}, = {}) req = build_request(:delete_data_accessor, params) req.send_request() end |
#delete_data_source(params = {}) ⇒ Struct
Deletes an Amazon Q Business data source connector. While the data source is being deleted, the ‘Status` field returned by a call to the `DescribeDataSource` API is set to `DELETING`.
2579 2580 2581 2582 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2579 def delete_data_source(params = {}, = {}) req = build_request(:delete_data_source, params) req.send_request() end |
#delete_group(params = {}) ⇒ Struct
Deletes a group so that all users and sub groups that belong to the group can no longer access documents only available to that group. For example, after deleting the group “Summer Interns”, all interns who belonged to that group no longer see intern-only documents in their chat results.
If you want to delete, update, or replace users or sub groups of a group, you need to use the ‘PutGroup` operation. For example, if a user in the group “Engineering” leaves the engineering team and another user takes their place, you provide an updated list of users or sub groups that belong to the “Engineering” group when calling `PutGroup`.
2633 2634 2635 2636 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2633 def delete_group(params = {}, = {}) req = build_request(:delete_group, params) req.send_request() end |
#delete_index(params = {}) ⇒ Struct
Deletes an Amazon Q Business index.
2660 2661 2662 2663 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2660 def delete_index(params = {}, = {}) req = build_request(:delete_index, params) req.send_request() end |
#delete_plugin(params = {}) ⇒ Struct
Deletes an Amazon Q Business plugin.
2687 2688 2689 2690 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2687 def delete_plugin(params = {}, = {}) req = build_request(:delete_plugin, params) req.send_request() end |
#delete_retriever(params = {}) ⇒ Struct
Deletes the retriever used by an Amazon Q Business application.
2714 2715 2716 2717 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2714 def delete_retriever(params = {}, = {}) req = build_request(:delete_retriever, params) req.send_request() end |
#delete_user(params = {}) ⇒ Struct
Deletes a user by email id.
2741 2742 2743 2744 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2741 def delete_user(params = {}, = {}) req = build_request(:delete_user, params) req.send_request() end |
#delete_web_experience(params = {}) ⇒ Struct
Deletes an Amazon Q Business web experience.
2768 2769 2770 2771 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2768 def delete_web_experience(params = {}, = {}) req = build_request(:delete_web_experience, params) req.send_request() end |
#disassociate_permission(params = {}) ⇒ Struct
Removes a permission policy from a Amazon Q Business application, revoking the cross-account access that was previously granted to an ISV. This operation deletes the specified policy statement from the application’s permission policy.
2797 2798 2799 2800 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2797 def (params = {}, = {}) req = build_request(:disassociate_permission, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets information about an existing Amazon Q Business application.
2864 2865 2866 2867 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2864 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_chat_controls_configuration(params = {}) ⇒ Types::GetChatControlsConfigurationResponse
Gets information about chat controls configured for an existing Amazon Q Business application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2939 2940 2941 2942 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 2939 def get_chat_controls_configuration(params = {}, = {}) req = build_request(:get_chat_controls_configuration, params) req.send_request() end |
#get_chat_response_configuration(params = {}) ⇒ Types::GetChatResponseConfigurationResponse
Retrieves detailed information about a specific chat response configuration from an Amazon Q Business application. This operation returns the complete configuration settings and metadata.
3011 3012 3013 3014 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3011 def get_chat_response_configuration(params = {}, = {}) req = build_request(:get_chat_response_configuration, params) req.send_request() end |
#get_data_accessor(params = {}) ⇒ Types::GetDataAccessorResponse
Retrieves information about a specified data accessor. This operation returns details about the data accessor, including its display name, unique identifier, Amazon Resource Name (ARN), the associated Amazon Q Business application and IAM Identity Center application, the IAM role for the ISV, the action configurations, and the timestamps for when the data accessor was created and last updated.
3117 3118 3119 3120 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3117 def get_data_accessor(params = {}, = {}) req = build_request(:get_data_accessor, params) req.send_request() end |
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Gets information about an existing Amazon Q Business data source connector.
3226 3227 3228 3229 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3226 def get_data_source(params = {}, = {}) req = build_request(:get_data_source, params) req.send_request() end |
#get_document_content(params = {}) ⇒ Types::GetDocumentContentResponse
Retrieves the content of a document that was ingested into Amazon Q Business. This API validates user authorization against document ACLs before returning a pre-signed URL for secure document access. You can download or view source documents referenced in chat responses through the URL.
3284 3285 3286 3287 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3284 def get_document_content(params = {}, = {}) req = build_request(:get_document_content, params) req.send_request() end |
#get_group(params = {}) ⇒ Types::GetGroupResponse
Describes a group by group name.
3333 3334 3335 3336 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3333 def get_group(params = {}, = {}) req = build_request(:get_group, params) req.send_request() end |
#get_index(params = {}) ⇒ Types::GetIndexResponse
Gets information about an existing Amazon Q Business index.
3395 3396 3397 3398 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3395 def get_index(params = {}, = {}) req = build_request(:get_index, params) req.send_request() end |
#get_media(params = {}) ⇒ Types::GetMediaResponse
Returns the image bytes corresponding to a media object. If you have implemented your own application with the Chat and ChatSync APIs, and have enabled content extraction from visual data in Amazon Q Business, you use the GetMedia API operation to download the images so you can show them in your UI with responses.
For more information, see [Extracting semantic meaning from images and visuals].
[1]: docs.aws.amazon.com/amazonq/latest/qbusiness-ug/extracting-meaning-from-images.html
3451 3452 3453 3454 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3451 def get_media(params = {}, = {}) req = build_request(:get_media, params) req.send_request() end |
#get_plugin(params = {}) ⇒ Types::GetPluginResponse
Gets information about an existing Amazon Q Business plugin.
3516 3517 3518 3519 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3516 def get_plugin(params = {}, = {}) req = build_request(:get_plugin, params) req.send_request() end |
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Retrieves the current permission policy for a Amazon Q Business application. The policy is returned as a JSON-formatted string and defines the IAM actions that are allowed or denied for the application’s resources.
3547 3548 3549 3550 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3547 def get_policy(params = {}, = {}) req = build_request(:get_policy, params) req.send_request() end |
#get_retriever(params = {}) ⇒ Types::GetRetrieverResponse
Gets information about an existing retriever used by an Amazon Q Business application.
3610 3611 3612 3613 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3610 def get_retriever(params = {}, = {}) req = build_request(:get_retriever, params) req.send_request() end |
#get_user(params = {}) ⇒ Types::GetUserResponse
Describes the universally unique identifier (UUID) associated with a local user in a data source.
3646 3647 3648 3649 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3646 def get_user(params = {}, = {}) req = build_request(:get_user, params) req.send_request() end |
#get_web_experience(params = {}) ⇒ Types::GetWebExperienceResponse
Gets information about an existing Amazon Q Business web experience.
3724 3725 3726 3727 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3724 def get_web_experience(params = {}, = {}) req = build_request(:get_web_experience, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists Amazon Q Business applications.
<note markdown=“1”> Amazon Q Business applications may securely transmit data for processing across Amazon Web Services Regions within your geography. For more information, see [Cross region inference in Amazon Q Business].
</note>
[1]: docs.aws.amazon.com/amazonq/latest/qbusiness-ug/cross-region-inference.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3781 3782 3783 3784 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3781 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_attachments(params = {}) ⇒ Types::ListAttachmentsResponse
Gets a list of attachments associated with an Amazon Q Business web experience or a list of attachements associated with a specific Amazon Q Business conversation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3847 3848 3849 3850 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3847 def (params = {}, = {}) req = build_request(:list_attachments, params) req.send_request() end |
#list_chat_response_configurations(params = {}) ⇒ Types::ListChatResponseConfigurationsResponse
Retrieves a list of all chat response configurations available in a specified Amazon Q Business application. This operation returns summary information about each configuration to help administrators manage and select appropriate response settings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3901 3902 3903 3904 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3901 def list_chat_response_configurations(params = {}, = {}) req = build_request(:list_chat_response_configurations, params) req.send_request() end |
#list_conversations(params = {}) ⇒ Types::ListConversationsResponse
Lists one or more Amazon Q Business conversations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3952 3953 3954 3955 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 3952 def list_conversations(params = {}, = {}) req = build_request(:list_conversations, params) req.send_request() end |
#list_data_accessors(params = {}) ⇒ Types::ListDataAccessorsResponse
Lists the data accessors for a Amazon Q Business application. This operation returns a paginated list of data accessor summaries, including the friendly name, unique identifier, ARN, associated IAM role, and creation/update timestamps for each data accessor.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4007 4008 4009 4010 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4007 def list_data_accessors(params = {}, = {}) req = build_request(:list_data_accessors, params) req.send_request() end |
#list_data_source_sync_jobs(params = {}) ⇒ Types::ListDataSourceSyncJobsResponse
Get information about an Amazon Q Business data source connector synchronization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4086 4087 4088 4089 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4086 def list_data_source_sync_jobs(params = {}, = {}) req = build_request(:list_data_source_sync_jobs, params) req.send_request() end |
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists the Amazon Q Business data source connectors that you have created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4142 4143 4144 4145 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4142 def list_data_sources(params = {}, = {}) req = build_request(:list_data_sources, params) req.send_request() end |
#list_documents(params = {}) ⇒ Types::ListDocumentsResponse
A list of documents attached to an index.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4199 4200 4201 4202 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4199 def list_documents(params = {}, = {}) req = build_request(:list_documents, params) req.send_request() end |
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Provides a list of groups that are mapped to users.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4259 4260 4261 4262 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4259 def list_groups(params = {}, = {}) req = build_request(:list_groups, params) req.send_request() end |
#list_indices(params = {}) ⇒ Types::ListIndicesResponse
Lists the Amazon Q Business indices you have created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4308 4309 4310 4311 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4308 def list_indices(params = {}, = {}) req = build_request(:list_indices, params) req.send_request() end |
#list_messages(params = {}) ⇒ Types::ListMessagesResponse
Gets a list of messages associated with an Amazon Q Business web experience.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4412 4413 4414 4415 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4412 def (params = {}, = {}) req = build_request(:list_messages, params) req.send_request() end |
#list_plugin_actions(params = {}) ⇒ Types::ListPluginActionsResponse
Lists configured Amazon Q Business actions for a specific plugin in an Amazon Q Business application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4464 4465 4466 4467 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4464 def list_plugin_actions(params = {}, = {}) req = build_request(:list_plugin_actions, params) req.send_request() end |
#list_plugin_type_actions(params = {}) ⇒ Types::ListPluginTypeActionsResponse
Lists configured Amazon Q Business actions for any plugin type—both built-in and custom.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4511 4512 4513 4514 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4511 def list_plugin_type_actions(params = {}, = {}) req = build_request(:list_plugin_type_actions, params) req.send_request() end |
#list_plugin_type_metadata(params = {}) ⇒ Types::ListPluginTypeMetadataResponse
Lists metadata for all Amazon Q Business plugin types.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4552 4553 4554 4555 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4552 def (params = {}, = {}) req = build_request(:list_plugin_type_metadata, params) req.send_request() end |
#list_plugins(params = {}) ⇒ Types::ListPluginsResponse
Lists configured Amazon Q Business plugins.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4603 4604 4605 4606 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4603 def list_plugins(params = {}, = {}) req = build_request(:list_plugins, params) req.send_request() end |
#list_retrievers(params = {}) ⇒ Types::ListRetrieversResponse
Lists the retriever used by an Amazon Q Business application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4651 4652 4653 4654 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4651 def list_retrievers(params = {}, = {}) req = build_request(:list_retrievers, params) req.send_request() end |
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsResponse
Lists all subscriptions created in an Amazon Q Business application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4701 4702 4703 4704 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4701 def list_subscriptions(params = {}, = {}) req = build_request(:list_subscriptions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags associated with a specified resource. Amazon Q Business applications and data sources can have tags associated with them.
4734 4735 4736 4737 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4734 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_web_experiences(params = {}) ⇒ Types::ListWebExperiencesResponse
Lists one or more Amazon Q Business Web Experiences.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4783 4784 4785 4786 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4783 def list_web_experiences(params = {}, = {}) req = build_request(:list_web_experiences, params) req.send_request() end |
#put_feedback(params = {}) ⇒ Struct
Enables your end user to provide feedback on their Amazon Q Business generated chat responses.
4831 4832 4833 4834 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4831 def put_feedback(params = {}, = {}) req = build_request(:put_feedback, params) req.send_request() end |
#put_group(params = {}) ⇒ Struct
Create, or updates, a mapping of users—who have access to a document—to groups.
You can also map sub groups to groups. For example, the group “Company Intellectual Property Teams” includes sub groups “Research” and “Engineering”. These sub groups include their own list of users or people who work in these teams. Only users who work in research and engineering, and therefore belong in the intellectual property group, can see top-secret company documents in their Amazon Q Business chat results.
There are two options for creating groups, either passing group members inline or using an S3 file via the S3PathForGroupMembers field. For inline groups, there is a limit of 1000 members per group and for provided S3 files there is a limit of 100 thousand members. When creating a group using an S3 file, you provide both an S3 file and a ‘RoleArn` for Amazon Q Buisness to access the file.
4925 4926 4927 4928 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 4925 def put_group(params = {}, = {}) req = build_request(:put_group, params) req.send_request() end |
#search_relevant_content(params = {}) ⇒ Types::SearchRelevantContentResponse
Searches for relevant content in a Amazon Q Business application based on a query. This operation takes a search query text, the Amazon Q Business application identifier, and optional filters (such as content source and maximum results) as input. It returns a list of relevant content items, where each item includes the content text, the unique document identifier, the document title, the document URI, any relevant document attributes, and score attributes indicating the confidence level of the relevance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5079 5080 5081 5082 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5079 def search_relevant_content(params = {}, = {}) req = build_request(:search_relevant_content, params) req.send_request() end |
#start_data_source_sync_job(params = {}) ⇒ Types::StartDataSourceSyncJobResponse
Starts a data source connector synchronization job. If a synchronization job is already in progress, Amazon Q Business returns a ‘ConflictException`.
5118 5119 5120 5121 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5118 def start_data_source_sync_job(params = {}, = {}) req = build_request(:start_data_source_sync_job, params) req.send_request() end |
#stop_data_source_sync_job(params = {}) ⇒ Struct
Stops an Amazon Q Business data source connector synchronization job already in progress.
5151 5152 5153 5154 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5151 def stop_data_source_sync_job(params = {}, = {}) req = build_request(:stop_data_source_sync_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tag to the specified Amazon Q Business application or data source resource. If the tag already exists, the existing value is replaced with the new value.
5187 5188 5189 5190 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5187 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from an Amazon Q Business application or a data source.
5216 5217 5218 5219 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5216 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_application(params = {}) ⇒ Struct
Updates an existing Amazon Q Business application.
<note markdown=“1”> Amazon Q Business applications may securely transmit data for processing across Amazon Web Services Regions within your geography. For more information, see [Cross region inference in Amazon Q Business].
</note>
<note markdown=“1”> An Amazon Q Apps service-linked role will be created if it’s absent in the Amazon Web Services account when ‘QAppsConfiguration` is enabled in the request. For more information, see [Using service-linked roles for Q Apps].
</note>
[1]: docs.aws.amazon.com/amazonq/latest/qbusiness-ug/cross-region-inference.html [2]: docs.aws.amazon.com/amazonq/latest/qbusiness-ug/using-service-linked-roles-qapps.html
5310 5311 5312 5313 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5310 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_chat_controls_configuration(params = {}) ⇒ Struct
Updates a set of chat controls configured for an existing Amazon Q Business application.
5448 5449 5450 5451 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5448 def update_chat_controls_configuration(params = {}, = {}) req = build_request(:update_chat_controls_configuration, params) req.send_request() end |
#update_chat_response_configuration(params = {}) ⇒ Struct
Updates an existing chat response configuration in an Amazon Q Business application. This operation allows administrators to modify configuration settings, display name, and response parameters to refine how the system generates responses.
5512 5513 5514 5515 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5512 def update_chat_response_configuration(params = {}, = {}) req = build_request(:update_chat_response_configuration, params) req.send_request() end |
#update_data_accessor(params = {}) ⇒ Struct
Updates an existing data accessor. This operation allows modifying the action configurations (the allowed actions and associated filters) and the display name of the data accessor. It does not allow changing the IAM role associated with the data accessor or other core properties of the data accessor.
5649 5650 5651 5652 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5649 def update_data_accessor(params = {}, = {}) req = build_request(:update_data_accessor, params) req.send_request() end |
#update_data_source(params = {}) ⇒ Struct
Updates an existing Amazon Q Business data source connector.
5798 5799 5800 5801 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5798 def update_data_source(params = {}, = {}) req = build_request(:update_data_source, params) req.send_request() end |
#update_index(params = {}) ⇒ Struct
Updates an Amazon Q Business index.
5858 5859 5860 5861 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5858 def update_index(params = {}, = {}) req = build_request(:update_index, params) req.send_request() end |
#update_plugin(params = {}) ⇒ Struct
Updates an Amazon Q Business plugin.
5931 5932 5933 5934 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 5931 def update_plugin(params = {}, = {}) req = build_request(:update_plugin, params) req.send_request() end |
#update_retriever(params = {}) ⇒ Struct
Updates the retriever used for your Amazon Q Business application.
6000 6001 6002 6003 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 6000 def update_retriever(params = {}, = {}) req = build_request(:update_retriever, params) req.send_request() end |
#update_subscription(params = {}) ⇒ Types::UpdateSubscriptionResponse
Updates the pricing tier for an Amazon Q Business subscription. Upgrades are instant. Downgrades apply at the start of the next month. Subscription tier determines feature access for the user. For more information on subscriptions and pricing tiers, see [Amazon Q Business pricing].
6049 6050 6051 6052 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 6049 def update_subscription(params = {}, = {}) req = build_request(:update_subscription, params) req.send_request() end |
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Updates a information associated with a user id.
6114 6115 6116 6117 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 6114 def update_user(params = {}, = {}) req = build_request(:update_user, params) req.send_request() end |
#update_web_experience(params = {}) ⇒ Struct
Updates an Amazon Q Business web experience.
6233 6234 6235 6236 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 6233 def update_web_experience(params = {}, = {}) req = build_request(:update_web_experience, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6262 6263 6264 |
# File 'lib/aws-sdk-qbusiness/client.rb', line 6262 def waiter_names [] end |